package com.brilliance.isc.funds.vo;
import com.brilliance.isc.common.vo.PageVo;
import com.fasterxml.jackson.annotation.JsonFormat;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import lombok.Data;
import lombok.NoArgsConstructor;
import java.util.Date;
import java.math.BigDecimal;
import java.util.List;

/**
 * @description:
 * @author: hulei
 * @create: 2024-09-25 15:10
 **/

/**
 * TABLE:fxd:
 *
 *  `INR CHAR(8)`：`INR` 字段，字符类型，长度为 8。
 *    - `OWNREF CHAR(16)`：`OWNREF` 字段，字符类型，长度为 16。
 *    - `NAM CHAR(40)`：`NAM` 字段，字符类型，长度为 40。
 *    - `OPNDAT DATE`：`OPNDAT` 字段，日期类型。
 *    - `OWNUSR CHAR(8)`：`OWNUSR` 字段，字符类型，长度为 8。
 *    - `FXTYP CHAR(2)`：`FXTYP` 字段，字符类型，长度为 2。
 *    - `RAT NUMERIC(12,6)`：`RAT` 字段，数值类型，总共 12 位，小数点后 6 位。
 *    - `MIDRAT NUMERIC(12,6)`：`MIDRAT` 字段，数值类型，总共 12 位，小数点后 6 位。
 *    - `QUOREF CHAR(16)`：`QUOREF` 字段，字符类型，长度为 16。
 *    - `FUDREF CHAR(16)`：`FUDREF` 字段，字符类型，长度为 16。
 *    - `VALDAT DATE`：`VALDAT` 字段，日期类型。
 *    - `CNFDAT DATE`：`CNFDAT` 字段，日期类型。
 *    - `SETDAT DATE`：`SETDAT` 字段，日期类型。
 *    - `SETDATFRM DATE`：`SETDATFRM` 字段，日期类型。
 *    - `SETDATTO DATE`：`SETDATTO` 字段，日期类型。
 *    - `CLSDAT DATE`：`CLSDAT` 字段，日期类型。
 *    - `VER CHAR(4)`：`VER` 字段，字符类型，长度为 4。
 *    - `BRANCHINR CHAR(8)`：`BRANCHINR` 字段，字符类型，长度为 8。
 *    - `BCHKEYINR CHAR(8)`：`BCHKEYINR` 字段，字符类型，长度为 8。
 *    - `TRDINT CHAR(3)`：`TRDINT` 字段，字符类型，长度为 3。
 *    - `TRDOUT CHAR(3)`：`TRDOUT` 字段，字符类型，长度为 3。
 *    - `TRNMAN CHAR(2)`：`TRNMAN` 字段，字符类型，长度为 2。
 *    - `ACC CHAR(21)`：`ACC` 字段，字符类型，长度为 21。
 *    - `ACC2 CHAR(21)`：`ACC2` 字段，字符类型，长度为 21。
 *    - `USR CHAR(8)`：`USR` 字段，字符类型，长度为 8。
 *    - `DSP CHAR(2)`：`DSP` 字段，字符类型，长度为 2。
 *    - `DSP2 CHAR(2)`：`DSP2` 字段，字符类型，长度为 2。
 *    - `CSHPCT NUMERIC(5,2)`：`CSHPCT` 字段，数值类型，总共 5 位，小数点后 2 位。
 *    - `RAT1 NUMERIC(12,6)`：`RAT1` 字段，数值类型，总共 12 位，小数点后 6 位。
 *    - `ACCMNG CHAR(8)`：`ACCMNG` 字段，字符类型，长度为 8。
 *    - `HDBCH CHAR(8)`：`HDBCH` 字段，字符类型，长度为 8。
 *    - `ETYEXTKEY CHAR(8)`：`ETYEXTKEY` 字段，字符类型，长度为 8。
 *
 *              ownref: "",			//  业务编号    		.infcon.seaownref
 * 				nam: "",			//  参与方名称Name		.infcon.nam
 * 				fxtyp,      //平盘类型
 * 				trdint,    //结售汇类型
 * 				fudref,     //资金部编号
 * 				//searef:"",			//  参与方参考号		.infcon.searef
 * 				//seapty:"",			//  参与方名称/BIC		.infcon.seapty
 * 				opndatfrom: "",			//  成交有效日期自		.infcon.opndatfrom
 * 				opndatto: "",			//  Open Date to		.infcon.opndatto
 * 				seacur: "",			//  币种		.infcon.seacur
 * 				seaamtfr: "",			//  金额自		.infcon.seaamtfr
 * 				seaamtto: "",			//  Amount to		.infcon.seaamtto
 * 				//trnman,    //交易主体
 * 				acc,   //外币结算账号
 * 				acc2,   //本币结算账号
 * 				ownusr,    //资金部经办人
 * 				usr,    //营运部经办人
 */


@Data
@NoArgsConstructor
@JsonIgnoreProperties(ignoreUnknown = true)
public class FxdVo extends PageVo {

    /**
     * 汇款主表唯一编号
     */
   // private String inr;
    /**
     *  汇款业务编号
     */
    private String seaownref;
    /**
     * 客户号/名称
     */
    private String nam;

    /**
     * 机构编号
     */
    private String bchkeyinr;
    /**
     * 机构编码
     */
    private String branchinr;


    /**
     * 汇款开始日期
     */
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date opndatfrom;
    /**
     * 汇款截止日期
     */
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date opndatto;


//    /**
//     * 汇款邮路
//     */
//    private String route;


    private String fxtyp;

    private String trdint;


    private String fudref;




    /**
     * //币种
     */
    private String seacur;
    /**
     * //金额
     */
    private BigDecimal seaamt;
    /**
     * //金额
     */
    private BigDecimal seaamtfr;
    /**
     * //金额
     */
    private BigDecimal seaamtto;
    /**
     * swift类型
     */
   // private String msgtyp;
    /**
     * 国家代码
     */
   // private String countcode;
    /**
     * 同名划转标志
     */
   // private String tsnflg;
    /**
     * 机构
     */
   // private String brainr;
    /**
     * 柜员
     */
    private String ownusr;
    private String usr;
    /**
     * 前端渠道
     */
   // private String channel;
    /**
     * 渠道业务编号
     */
   // private String chnref;

    /**
     * 排序字段
     */
  //  private String column;

    /**
     * 正序倒序
     */
  //  private String order;

}
